==> haskell-nanospec-0.2.2-538.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-nanospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nanospec
version:              0.2.2
visibility:           public
id:                   nanospec-0.2.2-1go4OqTTLFpKadRRi1i4Tl
key:                  nanospec-0.2.2-1go4OqTTLFpKadRRi1i4Tl
license:              MIT
copyright:            (c) 2012-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/nanospec#readme
synopsis:             A lightweight implementation of a subset of Hspec'\''s API
description:
    A lightweight implementation of a subset of Hspec'\''s API with minimal dependencies.

category:             Testing
abi:                  079a74d492a654a42499b9498352e5f7
exposed-modules:      Test.Hspec
hidden-modules:       Paths_nanospec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/nanospec-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/nanospec-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/nanospec-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nanospec
hs-libraries:         HSnanospec-0.2.2-1go4OqTTLFpKadRRi1i4Tl
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-nanospec/html/nanospec.haddock
haddock-html:         /usr/share/doc/haskell-nanospec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nanospec-0.2.2-540-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-nanospec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nanospec
version:              0.2.2
visibility:           public
id:                   nanospec-0.2.2-8HPtv2ysfVmAulB7RM8hEk
key:                  nanospec-0.2.2-8HPtv2ysfVmAulB7RM8hEk
license:              MIT
copyright:            (c) 2012-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/nanospec#readme
synopsis:             A lightweight implementation of a subset of Hspec'\''s API
description:
    A lightweight implementation of a subset of Hspec'\''s API with minimal dependencies.

category:             Testing
abi:                  33b6f65f906b977b7da7f8c23604dabc
exposed-modules:      Test.Hspec
hidden-modules:       Paths_nanospec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/nanospec-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/nanospec-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/nanospec-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nanospec
hs-libraries:         HSnanospec-0.2.2-8HPtv2ysfVmAulB7RM8hEk
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-nanospec/html/nanospec.haddock
haddock-html:         /usr/share/doc/haskell-nanospec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
